@@ -330,8 +330,13 @@ inferIxSet ixset typeName calName entryPoints
     = do calInfo <- reify calName
          typeInfo <- reify typeName
          let (context,binders) = case typeInfo of
+#if MIN_VERSION_template_haskell(2,11,0)
+                                 TyConI (DataD ctxt _ nms _ _ _) -> (ctxt,nms)
+                                 TyConI (NewtypeD ctxt _ nms _ _ _) -> (ctxt,nms)
+#else
                                  TyConI (DataD ctxt _ nms _ _) -> (ctxt,nms)
                                  TyConI (NewtypeD ctxt _ nms _ _) -> (ctxt,nms)
+#endif
                                  TyConI (TySynD _ nms _) -> ([],nms)
                                  _ -> error "IxSet.inferIxSet typeInfo unexpected match"
 
@@ -351,7 +356,11 @@ inferIxSet ixset typeName calName entryPoints
                 dataCtxCon <- sequence dataCtxConQ
                 return (context ++ dataCtxCon)
          case calInfo of
+#if MIN_VERSION_template_haskell(2,11,0)
+           VarI _ t _ ->
+#else
            VarI _ t _ _ ->
+#endif
                let calType = getCalType t
                    getCalType (ForallT _names _ t') = getCalType t'
                    getCalType (AppT (AppT ArrowT _) t') = t'
